==> haskell-html-conduit-1.3.2.2-372-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 html-conduit
version:              1.3.2.2
visibility:           public
id:                   html-conduit-1.3.2.2-BejMjhjb0QNDnb2PFSxjnb
key:                  html-conduit-1.3.2.2-BejMjhjb0QNDnb2PFSxjnb
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/xml
synopsis:             Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.

category:             Web, Text, Conduit
abi:                  6eb4b4653d0b98ca152c592b4c45038e
exposed:              True
exposed-modules:      Text.HTML.DOM
hidden-modules:       Text.HTML.TagStream
import-dirs:          /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-conduit
hs-libraries:         HShtml-conduit-1.3.2.2-BejMjhjb0QNDnb2PFSxjnb
depends:
    attoparsec-0.14.4-8oph4y3j0I1GXQUqU3wi8s base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-I3Yz95F3VB23prC9ONLqsR
    conduit-extra-1.3.8-L5aEVN7ERPaAM0AjK09rWN containers-0.6.7
    resourcet-1.2.6-KWNBYKS1Nsa45KHyXSSfHy text-2.0.2
    transformers-0.5.6.2 xml-conduit-1.9.1.4-86ynJRlLKv1I6k3rZwrMdV
    xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:
    /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock

haddock-html:         /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-html-conduit-1.3.2.2-373-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 html-conduit
version:              1.3.2.2
visibility:           public
id:                   html-conduit-1.3.2.2-AUdClipQSYHFYKHGay5wrx
key:                  html-conduit-1.3.2.2-AUdClipQSYHFYKHGay5wrx
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/xml
synopsis:             Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.

category:             Web, Text, Conduit
abi:                  ab31f9184f8c9bbe7d53c18dcb393b25
exposed:              True
exposed-modules:      Text.HTML.DOM
hidden-modules:       Text.HTML.TagStream
import-dirs:          /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-conduit
hs-libraries:         HShtml-conduit-1.3.2.2-AUdClipQSYHFYKHGay5wrx
depends:
    attoparsec-0.14.4-4euoXrooDbuLZe6Xn3rp2d base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-7LhvtPy5XPV4LCu4wfXMeP
    conduit-extra-1.3.8-BIrQCx2fsV2HdQedayYVqN containers-0.6.7
    resourcet-1.2.6-1FDtq0UrUuZHM60NAflSwS text-2.0.2
    transformers-0.5.6.2 xml-conduit-1.9.1.4-GkCcWqtKyEaLTCbsrDZIQ5
    xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:
    /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock

haddock-html:         /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
